==> pegasus-support-1.6.22-sources.jar: com/thebeastshop/support/vo/exchange/ExchangeGoods.java <==
package com.thebeastshop.support.vo.exchange;

import com.thebeastshop.support.enums.exchange.ExchangeGoodsClassify;

import java.io.Serializable;
import java.util.List;

/**
 * @author feilong.gao
 * @Date 2018/5/23 15:14.
 * @Description
 */
public class ExchangeGoods implements Serializable {

    private static final long serialVersionUID = -9206619830887457411L;

    private Integer Id;
    private String code;
    private Boolean soldOut = Boolean.FALSE;
    private List<Integer> levelIds;
    private Integer point;
    private ExchangeGoodsClassify classify = ExchangeGoodsClassify.UNKNOWN;

    public Integer getId() {
        return Id;
    }

    public void setId(Integer id) {
        Id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public Boolean getSoldOut() {
        return soldOut;
    }

    public void setSoldOut(Boolean soldOut) {
        this.soldOut = soldOut;
    }

    public List<Integer> getLevelIds() {
        return levelIds;
    }

    public void setLevelIds(List<Integer> levelIds) {
        this.levelIds = levelIds;
    }

    public Integer getPoint() {
        return point;
    }

    public void setPoint(Integer point) {
        this.point = point;
    }

    public ExchangeGoodsClassify getClassify() {
        return classify;
    }

    public void setClassify(ExchangeGoodsClassify classify) {
        this.classify = classify;
    }


    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder("ExchangeGoods{");
        sb.append("Id=").append(Id);
        sb.append(", code='").append(code).append('\'');
        sb.append(", soldOut=").append(soldOut);
        sb.append(", levelIds=").append(levelIds);
        sb.append(", point=").append(point);
        sb.append(", classify=").append(classify);
        sb.append('}');
        return sb.toString();
    }
}

==> pegasus-support-1.6.30-sources.jar: com/thebeastshop/support/vo/exchange/ExchangeGoods.java <==
package com.thebeastshop.support.vo.exchange;

import com.thebeastshop.support.enums.exchange.ExchangeGoodsClassify;

import java.io.Serializable;
import java.util.List;

/**
 * @author feilong.gao
 * @Date 2018/5/23 15:14.
 * @Description
 */
public class ExchangeGoods implements Serializable {

    private static final long serialVersionUID = -9206619830887457411L;

    private Integer Id;
    private String code;
    private Boolean soldOut = Boolean.FALSE;
    private List<Integer> levelIds;
    private Integer point;
    private ExchangeGoodsClassify classify = ExchangeGoodsClassify.UNKNOWN;
    private Boolean online = Boolean.FALSE;

    public Integer getId() {
        return Id;
    }

    public void setId(Integer id) {
        Id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public Boolean getSoldOut() {
        return soldOut;
    }

    public void setSoldOut(Boolean soldOut) {
        this.soldOut = soldOut;
    }

    public List<Integer> getLevelIds() {
        return levelIds;
    }

    public void setLevelIds(List<Integer> levelIds) {
        this.levelIds = levelIds;
    }

    public Integer getPoint() {
        return point;
    }

    public void setPoint(Integer point) {
        this.point = point;
    }

    public ExchangeGoodsClassify getClassify() {
        return classify;
    }

    public void setClassify(ExchangeGoodsClassify classify) {
        this.classify = classify;
    }

    public Boolean getOnline() {
        return online;
    }

    public void setOnline(Boolean online) {
        this.online = online;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder("ExchangeGoods{");
        sb.append("Id=").append(Id);
        sb.append(", code='").append(code).append('\'');
        sb.append(", soldOut=").append(soldOut);
        sb.append(", levelIds=").append(levelIds);
        sb.append(", point=").append(point);
        sb.append(", classify=").append(classify);
        sb.append('}');
        return sb.toString();
    }
}
